@@ -5,6 +5,7 @@ import struct
 from binascii import a2b_base64
 
 from . import wrapper
+from .compat import int_from_byte
 
 class DAWG(object):
     """
@@ -73,7 +74,7 @@ class DAWG(object):
 
         This may be useful e.g. for handling single-character umlauts.
         """
-        return self._similar_keys("", key, self.dct.root(), replaces)
+        return self._similar_keys("", key, self.dct.ROOT, replaces)
 
     @classmethod
     def compile_replaces(cls, replaces):
@@ -95,14 +96,14 @@ class DAWG(object):
         Returns a list with keys of this DAWG that are prefixes of the ``key``.
         '''
         res = []
-        index = self.dct.root()
+        index = self.dct.ROOT
         if not isinstance(key, bytes):
             key = key.encode('utf8')
 
         pos = 1
 
-        for ch in bytearray(key):
-            index = self.dct.follow_char(ch, index)
+        for ch in key:
+            index = self.dct.follow_char(int_from_byte(ch), index)
             if not index:
                 break
 
@@ -128,7 +129,7 @@ class CompletionDAWG(DAWG):
         b_prefix = prefix.encode('utf8')
         res = []
 
-        index = self.dct.follow_bytes(b_prefix, self.dct.root())
+        index = self.dct.follow_bytes(b_prefix, self.dct.ROOT)
         if index is None:
             return res
 
@@ -142,7 +143,7 @@ class CompletionDAWG(DAWG):
 
     def iterkeys(self, prefix=""):
         b_prefix = prefix.encode('utf8')
-        index = self.dct.follow_bytes(b_prefix, self.dct.root())
+        index = self.dct.follow_bytes(b_prefix, self.dct.ROOT)
         if index is None:
             return
 
@@ -207,7 +208,7 @@ class BytesDAWG(CompletionDAWG):
         return self.b_get_value(key) or default
 
     def _follow_key(self, b_key):
-        index = self.dct.follow_bytes(b_key, self.dct.root())
+        index = self.dct.follow_bytes(b_key, self.dct.ROOT)
         if not index:
             return False
 
@@ -240,7 +241,7 @@ class BytesDAWG(CompletionDAWG):
             prefix = prefix.encode('utf8')
         res = []
 
-        index = self.dct.root()
+        index = self.dct.ROOT
 
         if prefix:
             index = self.dct.follow_bytes(prefix, index)
@@ -258,7 +259,7 @@ class BytesDAWG(CompletionDAWG):
         if not isinstance(prefix, bytes):
             prefix = prefix.encode('utf8')
 
-        index = self.dct.root()
+        index = self.dct.ROOT
 
         if prefix:
             index = self.dct.follow_bytes(prefix, index)
@@ -276,7 +277,7 @@ class BytesDAWG(CompletionDAWG):
             prefix = prefix.encode('utf8')
         res = []
 
-        index = self.dct.root()
+        index = self.dct.ROOT
         if prefix:
             index = self.dct.follow_bytes(prefix, index)
             if not index:
@@ -295,7 +296,7 @@ class BytesDAWG(CompletionDAWG):
         if not isinstance(prefix, bytes):
             prefix = prefix.encode('utf8')
 
-        index = self.dct.root()
+        index = self.dct.ROOT
         if prefix:
             index = self.dct.follow_bytes(prefix, index)
             if not index:
@@ -355,7 +356,7 @@ class BytesDAWG(CompletionDAWG):
         that maps single-char unicode sitrings to another single-char
         unicode strings.
         """
-        return self._similar_items("", key, self.dct.root(), replaces)
+        return self._similar_items("", key, self.dct.ROOT, replaces)
 
 
     def _similar_item_values(self, start_pos, key, index, replace_chars):
@@ -398,7 +399,7 @@ class BytesDAWG(CompletionDAWG):
         that maps single-char unicode sitrings to another single-char
         unicode strings.
         """
-        return self._similar_item_values(0, key, self.dct.root(), replaces)
+        return self._similar_item_values(0, key, self.dct.ROOT, replaces)
 
 
 class RecordDAWG(BytesDAWG):
